@@ -31,7 +31,6 @@ from nuitka.containers.oset import OrderedSet
 from nuitka.plugins.PluginBase import NuitkaPluginBase
 from nuitka.PythonVersions import python_version
 from nuitka.utils.FileOperations import getFileContentByLine
-from nuitka.utils.Importing import getSharedLibrarySuffix
 from nuitka.utils.ModuleNames import ModuleName
 from nuitka.utils.SharedLibraries import getPyWin32Dir, locateDLL
 from nuitka.utils.Utils import getOS, isWin32Windows
@@ -45,9 +44,6 @@ class NuitkaPluginPopularImplicitImports(NuitkaPluginBase):
     def __init__(self):
         NuitkaPluginBase.__init__(self)
 
-        self.pkg_utils_externals = None
-        self.opengl_plugins = None
-
     @staticmethod
     def isAlwaysEnabled():
         return True
@@ -63,170 +59,9 @@ class NuitkaPluginPopularImplicitImports(NuitkaPluginBase):
         """
         # Many variables, branches, due to the many cases, pylint: disable=too-many-branches,too-many-statements
 
-        top_level_package_name = full_name.getTopLevelPackageName()
-
-        if full_name.hasOneOfNamespaces("PyQt4", "PyQt5"):
-            if python_version < 0x300:
-                yield "atexit"
-
-            # These are alternatives now:
-            # TODO: One day it should avoid including both.
-            yield "sip"
-            if top_level_package_name == "PyQt5":
-                yield "PyQt5.sip"
-
-            _, child = full_name.splitPackageName()
-
-            def getChildNamed(*child_names):
-                for child_name in child_names:
-                    return top_level_package_name.getChildNamed(child_name)
-
-            if child in (
-                "QtGui",
-                "QtAssistant",
-                "QtDBus",
-                "QtDeclarative",
-                "QtSql",
-                "QtDesigner",
-                "QtHelp",
-                "QtNetwork",
-                "QtScript",
-                "QtQml",
-                "QtScriptTools",
-                "QtSvg",
-                "QtTest",
-                "QtWebKit",
-                "QtOpenGL",
-                "QtXml",
-                "QtXmlPatterns",
-                "QtPrintSupport",
-                "QtNfc",
-                "QtWebKitWidgets",
-                "QtBluetooth",
-                "QtMultimediaWidgets",
-                "QtQuick",
-                "QtWebChannel",
-                "QtWebSockets",
-                "QtX11Extras",
-                "_QOpenGLFunctions_2_0",
-                "_QOpenGLFunctions_2_1",
-                "_QOpenGLFunctions_4_1_Core",
-            ):
-                yield getChildNamed("QtCore")
-
-            if child in (
-                "QtDeclarative",
-                "QtWebKit",
-                "QtXmlPatterns",
-                "QtQml",
-                "QtPrintSupport",
-                "QtWebKitWidgets",
-                "QtMultimedia",
-                "QtMultimediaWidgets",
-                "QtQuick",
-                "QtQuickWidgets",
-                "QtWebSockets",
-                "QtWebEngineWidgets",
-            ):
-                yield getChildNamed("QtNetwork")
-
-            if child == "QtWebEngineWidgets":
-                yield getChildNamed("QtWebEngineCore")
-                yield getChildNamed("QtWebChannel")
-                yield getChildNamed("QtPrintSupport")
-            elif child == "QtScriptTools":
-                yield getChildNamed("QtScript")
-            elif child in (
-                "QtWidgets",
-                "QtDeclarative",
-                "QtDesigner",
-                "QtHelp",
-                "QtScriptTools",
-                "QtSvg",
-                "QtTest",
-                "QtWebKit",
-                "QtPrintSupport",
-                "QtWebKitWidgets",
-                "QtMultimedia",
-                "QtMultimediaWidgets",
-                "QtOpenGL",
-                "QtQuick",
-                "QtQuickWidgets",
-                "QtSql",
-                "_QOpenGLFunctions_2_0",
-                "_QOpenGLFunctions_2_1",
-                "_QOpenGLFunctions_4_1_Core",
-            ):
-                yield getChildNamed("QtGui")
-
-            if full_name in (
-                "PyQt5.QtDesigner",
-                "PyQt5.QtHelp",
-                "PyQt5.QtTest",
-                "PyQt5.QtPrintSupport",
-                "PyQt5.QtSvg",
-                "PyQt5.QtOpenGL",
-                "PyQt5.QtWebKitWidgets",
-                "PyQt5.QtMultimediaWidgets",
-                "PyQt5.QtQuickWidgets",
-                "PyQt5.QtSql",
-            ):
-                yield "PyQt5.QtWidgets"
-
-            if full_name in ("PyQt5.QtPrintSupport",):
-                yield "PyQt5.QtSvg"
-
-            if full_name in ("PyQt5.QtWebKitWidgets",):
-                yield "PyQt5.QtWebKit"
-                yield "PyQt5.QtPrintSupport"
-
-            if full_name in ("PyQt5.QtMultimediaWidgets",):
-                yield "PyQt5.QtMultimedia"
-
-            if full_name in ("PyQt5.QtQuick", "PyQt5.QtQuickWidgets"):
-                yield "PyQt5.QtQml"
-
-            if full_name in ("PyQt5.QtQuickWidgets", "PyQt5.QtQml"):
-                yield "PyQt5.QtQuick"
-
-            if full_name == "PyQt5.Qt":
-                yield "PyQt5.QtCore"
-                yield "PyQt5.QtDBus"
-                yield "PyQt5.QtGui"
-                yield "PyQt5.QtNetwork"
-                yield "PyQt5.QtNetworkAuth"
-                yield "PyQt5.QtSensors"
-                yield "PyQt5.QtSerialPort"
-                yield "PyQt5.QtMultimedia"
-                yield "PyQt5.QtQml"
-                yield "PyQt5.QtWidgets"
-
-        elif full_name == "sip" and python_version < 0x300:
+        if full_name == "sip" and python_version < 0x300:
             yield "enum"
 
-        elif full_name == "PySide.QtDeclarative":
-            yield "PySide.QtGui"
-        elif full_name == "PySide.QtHelp":
-            yield "PySide.QtGui"
-        elif full_name == "PySide.QtOpenGL":
-            yield "PySide.QtGui"
-        elif full_name == "PySide.QtScriptTools":
-            yield "PySide.QtScript"
-            yield "PySide.QtGui"
-        elif full_name == "PySide.QtSql":
-            yield "PySide.QtGui"
-        elif full_name == "PySide.QtSvg":
-            yield "PySide.QtGui"
-        elif full_name == "PySide.QtTest":
-            yield "PySide.QtGui"
-        elif full_name == "PySide.QtUiTools":
-            yield "PySide.QtGui"
-            yield "PySide.QtXml"
-        elif full_name == "PySide.QtWebKit":
-            yield "PySide.QtGui"
-        elif full_name == "PySide.phonon":
-            yield "PySide.QtGui"
-
         elif full_name == "lxml":
             yield "lxml.builder"
             yield "lxml.etree"
@@ -306,19 +141,6 @@ class NuitkaPluginPopularImplicitImports(NuitkaPluginBase):
             yield "engineio.async_drivers.threading"
             yield "engineio.async_drivers.tornado"
 
-        # start of eventlet imports ------------------------------------------
-        elif full_name == "eventlet":
-            yield "eventlet.hubs"
-
-        elif full_name == "eventlet.hubs":
-            yield "eventlet.hubs.epolls"
-            yield "eventlet.hubs.hub"
-            yield "eventlet.hubs.kqueue"
-            yield "eventlet.hubs.poll"
-            yield "eventlet.hubs.pyevent"
-            yield "eventlet.hubs.selects"
-            yield "eventlet.hubs.timer"
-
         # start of gevent imports --------------------------------------------
         elif full_name == "gevent":
             yield "_cffi_backend"
@@ -745,13 +567,6 @@ class NuitkaPluginPopularImplicitImports(NuitkaPluginBase):
             yield "matplotlib.backends.backend_webagg_core"
             yield "tornado"
 
-        elif full_name.hasOneOfNamespaces(
-            "matplotlib.backends.backend_qt4agg", "matplotlib.backends.backend_qt4"
-        ):
-            yield "matplotlib.backends.backend_qt4agg"
-            yield "matplotlib.backends.backend_qt4"
-            yield "PyQt4"
-
         elif full_name.hasOneOfNamespaces(
             "matplotlib.backends.backend_qt5agg", "matplotlib.backends.backend_qt5"
         ):
@@ -1117,8 +932,6 @@ class NuitkaPluginPopularImplicitImports(NuitkaPluginBase):
             yield "pandas._libs.tslibs.base"
         elif full_name == "pandas.core.window":
             yield "pandas._libs.skiplist"
-        elif full_name == "zmq.backend":
-            yield "zmq.backend.cython"
         elif full_name == "pandas._libs.testing":
             yield "cmath"
         elif full_name == "flask.app":
@@ -1166,6 +979,8 @@ class NuitkaPluginPopularImplicitImports(NuitkaPluginBase):
                 yield crypto_module_name + ".Hash._SHA512"
             elif full_name == crypto_module_name + ".Hash.MD5":
                 yield crypto_module_name + ".Hash._MD5"
+            elif full_name == crypto_module_name + ".Hash.keccak":
+                yield crypto_module_name + ".Hash._keccak"
             elif full_name == crypto_module_name + ".Protocol.KDF":
                 yield crypto_module_name + ".Cipher._Salsa20"
                 yield crypto_module_name + ".Protocol._scrypt"
@@ -1173,6 +988,8 @@ class NuitkaPluginPopularImplicitImports(NuitkaPluginBase):
                 yield crypto_module_name + ".Hash._ghash_portable"
             elif full_name == crypto_module_name + ".Cipher.ChaCha20":
                 yield crypto_module_name + ".Cipher._chacha20"
+            elif full_name == crypto_module_name + ".PublicKey.ECC":
+                yield crypto_module_name + ".PublicKey._ec_ws"
         elif full_name == "pycparser.c_parser":
             yield "pycparser.yacctab"
             yield "pycparser.lextab"
@@ -1206,12 +1023,18 @@ class NuitkaPluginPopularImplicitImports(NuitkaPluginBase):
                 yield full_name.getChildNamed("xorg")
         elif full_name == "_pytest._code.code":
             yield "py._path.local"
+        elif full_name == "pyreadstat._readstat_parser":
+            yield "pandas"
+        elif full_name == "cytoolz.itertoolz":
+            yield "cytoolz.utils"
+        elif full_name == "cytoolz.functoolz":
+            yield "cytoolz._signatures"
 
     def getImportsByFullname(self, full_name, module_filename):
         """Recursively create a set of imports for a fullname.
 
         Notes:
-            If an imported item has imported kids, call me again with each kid,
+            If an imported item has imported kids, call again with each new item,
             resulting in a leaf-only set (no more consequential kids).
         """
         result = OrderedSet()
@@ -1226,6 +1049,9 @@ class NuitkaPluginPopularImplicitImports(NuitkaPluginBase):
 
         checkImportsRecursive(full_name, module_filename)
 
+        if full_name in result:
+            result.remove(full_name)
+
         return result
 
     def getImplicitImports(self, module):
@@ -1238,50 +1064,35 @@ class NuitkaPluginPopularImplicitImports(NuitkaPluginBase):
                 yield used_module[0]
 
         if full_name == "pkg_resources.extern":
-            if self.pkg_utils_externals is None:
-                for line in getFileContentByLine(module.getCompileTimeFilename()):
-                    if line.startswith("names"):
-                        line = line.split("=")[-1].strip()
-                        parts = line.split(",")
+            for line in getFileContentByLine(module.getCompileTimeFilename()):
+                if line.startswith("names"):
+                    line = line.split("=")[-1].strip()
+                    parts = line.split(",")
 
-                        self.pkg_utils_externals = [part.strip("' ") for part in parts]
-
-                        break
-                else:
-                    self.pkg_utils_externals = ()
-
-            for pkg_util_external in self.pkg_utils_externals:
-                yield "pkg_resources._vendor." + pkg_util_external
+                    for part in parts:
+                        yield "pkg_resources._vendor." + part.strip("' ")
 
         elif full_name == "OpenGL":
-            if self.opengl_plugins is None:
-                self.opengl_plugins = []
-
-                for line in getFileContentByLine(module.getCompileTimeFilename()):
-                    if line.startswith("PlatformPlugin("):
-                        os_part, plugin_name_part = line[15:-1].split(",")
-                        os_part = os_part.strip("' ")
-                        plugin_name_part = plugin_name_part.strip(") '")
-                        plugin_name_part = plugin_name_part[
-                            : plugin_name_part.rfind(".")
-                        ]
-                        if os_part == "nt":
-                            if getOS() == "Windows":
-                                self.opengl_plugins.append(plugin_name_part)
-                        elif os_part.startswith("linux"):
-                            if getOS() == "Linux":
-                                self.opengl_plugins.append(plugin_name_part)
-                        elif os_part.startswith("darwin"):
-                            if getOS() == "Darwin":
-                                self.opengl_plugins.append(plugin_name_part)
-                        elif os_part.startswith(("posix", "osmesa", "egl")):
-                            if getOS() != "Windows":
-                                self.opengl_plugins.append(plugin_name_part)
-                        else:
-                            assert False, os_part
-
-            for opengl_plugin in self.opengl_plugins:
-                yield opengl_plugin
+            for line in getFileContentByLine(module.getCompileTimeFilename()):
+                if line.startswith("PlatformPlugin("):
+                    os_part, plugin_name_part = line[15:-1].split(",")
+                    os_part = os_part.strip("' ")
+                    plugin_name_part = plugin_name_part.strip(") '")
+                    plugin_name_part = plugin_name_part[: plugin_name_part.rfind(".")]
+                    if os_part == "nt":
+                        if getOS() == "Windows":
+                            yield plugin_name_part
+                    elif os_part.startswith("linux"):
+                        if getOS() == "Linux":
+                            yield plugin_name_part
+                    elif os_part.startswith("darwin"):
+                        if getOS() == "Darwin":
+                            yield plugin_name_part
+                    elif os_part.startswith(("posix", "osmesa", "egl")):
+                        if getOS() != "Windows":
+                            yield plugin_name_part
+                    else:
+                        assert False, os_part
 
         else:
             # create a flattened import set for full_name and yield from it
@@ -1497,18 +1308,6 @@ class NuitkaPluginPopularImplicitImports(NuitkaPluginBase):
 
             return result
 
-        elif full_name == "zmq.libzmq" and isWin32Windows():
-            # TODO: Very strange thing for zmq on Windows, needs the .pyd file in wrong dir too. Have
-            # this done in a dedicated form somewhere.
-            shutil.copyfile(
-                os.path.join(dist_dir, "zmq\\libzmq.pyd"),
-                os.path.join(
-                    dist_dir, "libzmq" + getSharedLibrarySuffix(preferred=True)
-                ),
-            )
-
-            return ()
-
         return ()
 
     unworthy_namespaces = (
